@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -142,7 +142,14 @@ def generate_deviceinfo_fastboot_content(bootimg=None):
         content += f"""\
         deviceinfo_header_version="{bootimg["header_version"]}"
         """
-    else:
+
+        if bootimg["header_version"] == "2":
+            content += f"""\
+            deviceinfo_append_dtb="false"
+            deviceinfo_flash_offset_dtb="{bootimg["dtb_offset"]}"
+            """
+
+    if "base" in bootimg.keys():
         content += f"""\
         deviceinfo_flash_offset_base="{bootimg["base"]}"
         deviceinfo_flash_offset_kernel="{bootimg["kernel_offset"]}"
@@ -232,7 +239,6 @@ def generate_apkbuild(args, pkgname, name, arch, flash_method):
         depends.append("mkbootimg")
     if flash_method == "0xffff":
         depends.append("uboot-tools")
-    depends.append("mesa-dri-gallium")
 
     # Whole APKBUILD
     depends.sort()
