@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.49.0"
+version = "1.50.1"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -28,6 +28,7 @@ arch_native = pmb.parse.arch.alpine_native()
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
 apk_tools_min_version = {"edge": "2.12.10-r1",
+                         "v3.17": "2.12.10-r1",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -508,7 +509,7 @@ necessary_kconfig_options_containers = {
             "CGROUP_HUGETLB": True,  # Optional section
         }
     },
-    ">=3.6 <6.1": {  # option has been dropped
+    ">=3.6 <6.1_rc1": {  # option has been dropped
         "all": {
             "MEMCG_SWAP": True,
         }
@@ -576,6 +577,51 @@ necessary_kconfig_options_netboot = {
     },
 }
 
+# Necessary wireguard & wg-quick kernel config options
+# From https://gitweb.gentoo.org/repo/gentoo.git/tree/net-vpn/wireguard-tools/wireguard-tools-1.0.20210914.ebuild?id=76aaa1eeb6f001baaa68e6946f917ebb091bbd9d # noqa
+necessary_kconfig_options_wireguard = {
+    ">=5.6_rc1": {  # all versions
+        "all": {  # all arches
+            "WIREGUARD": True,
+            "IP_ADVANCED_ROUTER": True,
+            "IP_MULTIPLE_TABLES": True,
+            "IPV6_MULTIPLE_TABLES": True,
+            "NF_TABLES": True,
+            "NF_TABLES_IPV4": True,
+            "NF_TABLES_IPV6": True,
+            "NFT_CT": True,
+            "NFT_FIB": True,
+            "NFT_FIB_IPV4": True,
+            "NFT_FIB_IPV6": True,
+            "NF_CONNTRACK_MARK": True,
+        },
+    },
+}
+
+# Necessary file system config options
+necessary_kconfig_options_filesystems = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "BTRFS_FS": True,
+            "EXFAT_FS": True,
+            "EXT4_FS": True,
+            "F2FS_FS": True,
+        },
+    },
+}
+
+# Various other kernel config options
+necessary_kconfig_options_community = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "INPUT_UINPUT": True,  # buffyboard
+            "LEDS_TRIGGER_TIMER": True,  # hfd-service
+            "NETFILTER_XT_MATCH_TCPMSS": True,  # change MTU, e.g. for Wireguard
+            "NETFILTER_XT_TARGET_TCPMSS": True,  # change MTU, e.g. for Wireguard
+        },
+    },
+}
+
 # Necessary UEFI boot config options
 necessary_kconfig_options_uefi = {
     ">=0.0.0": {  # all versions
@@ -891,7 +937,7 @@ flashers = {
     # Some Samsung devices need a 'boot.img' file, just like the one generated
     # fastboot compatible devices. Example: s7562, n7100
     "heimdall-bootimg": {
-        "depends": ["heimdall", "avbtool"],
+        "depends": [],  # pmaports.cfg: supported_heimdall_depends
         "actions": {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
