@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
@@ -20,7 +20,7 @@ def kernel(args):
         pmb.chroot.initfs.build(args, flavor, "rootfs_" + args.device)
 
     # Check kernel config
-    pmb.parse.kconfig.check(args, flavor)
+    pmb.parse.kconfig.check(args, flavor, must_exist=False)
 
     # Generate the paths and run the flasher
     if args.action_flasher == "boot":
@@ -88,11 +88,8 @@ def list_devices(args):
 
 
 def sideload(args):
-    method = args.flash_method or args.deviceinfo["flash_method"]
-    cfg = pmb.config.flashers[method]
-
     # Install depends
-    pmb.chroot.apk.install(args, cfg["depends"])
+    pmb.flasher.install_depends(args)
 
     # Mount the buildroot
     suffix = "buildroot_" + args.deviceinfo["arch"]
