@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import configparser
 import logging
@@ -109,8 +109,8 @@ def parse_channels_cfg(args):
                                            ...}} """
     # Cache during one pmbootstrap run
     cache_key = "pmb.helpers.git.parse_channels_cfg"
-    if args.cache[cache_key]:
-        return args.cache[cache_key]
+    if pmb.helpers.other.cache[cache_key]:
+        return pmb.helpers.other.cache[cache_key]
 
     # Read with configparser
     cfg = configparser.ConfigParser()
@@ -147,7 +147,7 @@ def parse_channels_cfg(args):
             value = cfg.get(channel, key)
             ret["channels"][channel_new][key] = value
 
-    args.cache[cache_key] = ret
+    pmb.helpers.other.cache[cache_key] = ret
     return ret
 
 
@@ -246,3 +246,29 @@ def is_outdated(path):
 
     date_outdated = time.time() - pmb.config.git_repo_outdated
     return date_head <= date_outdated
+
+
+def get_topdir(args, path):
+    """ :returns: a string with the top dir of the git repository, or an
+                  empty string if it's not a git repository. """
+    return pmb.helpers.run.user(args, ["git", "rev-parse", "--show-toplevel"],
+                                path, output_return=True, check=False).rstrip()
+
+
+def get_files(args, path):
+    """ Get all files inside a git repository, that are either already in the
+        git tree or are not in gitignore. Do not list deleted files. To be used
+        for creating a tarball of the git repository.
+        :param path: top dir of the git repository
+        :returns: all files in a git repository as list, relative to path """
+    ret = []
+    files = pmb.helpers.run.user(args, ["git", "ls-files"], path,
+                                 output_return=True).split("\n")
+    files += pmb.helpers.run.user(args, ["git", "ls-files",
+                                  "--exclude-standard", "--other"], path,
+                                  output_return=True).split("\n")
+    for file in files:
+        if os.path.exists(f"{path}/{file}"):
+            ret += [file]
+
+    return ret
