@@ -714,6 +714,19 @@ def install_system_image(args, size_reserve, suffix, step, steps,
         pmb.chroot.user(args, ["mv", "-f", sys_image_sparse, sys_image],
                         working_dir="/home/pmos/rootfs/")
 
+        # patch sparse image for Samsung devices if specified
+        samsungify_strategy = args.deviceinfo["flash_sparse_samsung_format"]
+        if samsungify_strategy:
+            logging.info("(native) convert sparse image into Samsung's sparse image format")
+            pmb.chroot.apk.install(args, ["sm-sparse-image-tool"])
+            sys_image = f"{args.device}.img"
+            sys_image_patched = f"{args.device}-patched.img"
+            pmb.chroot.user(args, ["sm_sparse_image_tool", "samsungify", "--strategy",
+                                   samsungify_strategy, sys_image, sys_image_patched],
+                            working_dir="/home/pmos/rootfs/")
+            pmb.chroot.user(args, ["mv", "-f", sys_image_patched, sys_image],
+                            working_dir="/home/pmos/rootfs/")
+
 
 def print_flash_info(args):
     """ Print flashing information, based on the deviceinfo data and the
@@ -790,7 +803,7 @@ def print_flash_info(args):
     if "flash_lk2nd" in flasher_actions and \
             os.path.exists(args.work + "/chroot_rootfs_" + args.device +
                            "/boot/lk2nd.img"):
-        logging.info(" * Your device supports and may even require"
+        logging.info("* Your device supports and may even require"
                      " flashing lk2nd. You should flash it before"
                      " flashing anything else. Use 'pmbootstrap flasher"
                      " flash_lk2nd' to do that.")
@@ -982,7 +995,14 @@ def create_device_rootfs(args, step, steps):
     setup_keymap(args)
 
     # Set timezone
-    pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
+    arch = args.deviceinfo["arch"]
+    package = pmb.helpers.package.get(args, "alpine-conf", arch)
+    version = package["version"].split("-r")[0]
+
+    if not pmb.parse.version.check_string(version, ">=3.14.0"):
+        pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
+    else:
+        pmb.chroot.root(args, ["setup-timezone", args.timezone], suffix)
 
     # Set locale
     if locale_is_set:
