@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
 import logging
@@ -79,8 +79,9 @@ def bootimg(args, path):
     if not os.path.exists(path):
         raise RuntimeError("Could not find file '" + path + "'")
 
-    logging.info("NOTE: You will be prompted for your sudo password, so we can"
-                 " set up a chroot to extract and analyze your boot.img file")
+    logging.info("NOTE: You will be prompted for your sudo/doas password, so"
+                 " we can set up a chroot to extract and analyze your"
+                 " boot.img file")
     pmb.chroot.apk.install(args, ["file", "unpackbootimg"])
 
     temp_path = pmb.chroot.other.tempfolder(args, "/tmp/bootimg_parser")
@@ -118,15 +119,15 @@ def bootimg(args, path):
                     working_dir=temp_path)
 
     output = {}
-    header_version = None
+    header_version = 0
     # Get base, offsets, pagesize, cmdline and qcdt info
     # This file does not exist for example for qcdt images
     if os.path.isfile(f"{bootimg_path}-header_version"):
         with open(f"{bootimg_path}-header_version", 'r') as f:
             header_version = int(f.read().replace('\n', ''))
+            output["header_version"] = str(header_version)
 
-    if header_version is not None and header_version >= 3:
-        output["header_version"] = str(header_version)
+    if header_version >= 3:
         output["pagesize"] = "4096"
     else:
         with open(f"{bootimg_path}-base", 'r') as f:
@@ -146,6 +147,11 @@ def bootimg(args, path):
         with open(f"{bootimg_path}-pagesize", 'r') as f:
             output["pagesize"] = f.read().replace('\n', '')
 
+        if header_version == 2:
+            with open(f"{bootimg_path}-dtb_offset", 'r') as f:
+                output["dtb_offset"] = ("0x%08x"
+                                        % int(f.read().replace('\n', ''), 16))
+
     output["qcdt"] = ("true" if os.path.isfile(f"{bootimg_path}-dt") and
                       os.path.getsize(f"{bootimg_path}-dt") > 0 else "false")
     output["mtk_mkimage"] = ("true" if check_mtk_bootimg(bootimg_path)
