@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import pmb.chroot
@@ -19,7 +19,7 @@ def package_from_aports(args, pkgname_depend):
         return None
 
     # Parse its version
-    apkbuild = pmb.parse.apkbuild(args, aport + "/APKBUILD")
+    apkbuild = pmb.parse.apkbuild(f"{aport}/APKBUILD")
     pkgname = apkbuild["pkgname"]
     version = apkbuild["pkgver"] + "-r" + apkbuild["pkgrel"]
 
@@ -116,13 +116,15 @@ def recurse(args, pkgnames, suffix="native"):
                    has multiple providers, we look at the installed packages in
                    the chroot to make a decision (see package_provider()).
     :returns: list of pkgnames: consists of the initial pkgnames plus all
-              depends
+              depends. Dependencies explicitly marked as conflicting are
+              prefixed with !.
     """
     logging.debug(f"({suffix}) calculate depends of {', '.join(pkgnames)} "
                   "(pmbootstrap -v for details)")
 
     # Iterate over todo-list until is is empty
     todo = list(pkgnames)
+    required_by = {}
     ret = []
     while len(todo):
         # Skip already passed entries
@@ -130,6 +132,10 @@ def recurse(args, pkgnames, suffix="native"):
         if pkgname_depend in ret:
             continue
 
+        # Check if the dependency is explicitly marked as conflicting
+        is_conflict = pkgname_depend.startswith("!")
+        pkgname_depend = pkgname_depend.lstrip("!")
+
         # Get depends and pkgname from aports
         pkgnames_install = list(ret) + todo
         package = package_from_aports(args, pkgname_depend)
@@ -138,18 +144,36 @@ def recurse(args, pkgnames, suffix="native"):
 
         # Nothing found
         if not package:
+            if is_conflict:
+                # This package was probably dropped from the repos, so we don't
+                # care if it doesn't exist since it's a conflicting depend that
+                # wouldn't be installed anyways.
+                continue
+            source = 'world'
+            if pkgname_depend in required_by:
+                source = ', '.join(required_by[pkgname_depend])
             raise RuntimeError(f"Could not find dependency '{pkgname_depend}' "
-                               "in any aports folder or APKINDEX. See:"
-                               " <https://postmarketos.org/depends>")
+                               "in checked out pmaports dir or any APKINDEX. "
+                               f"Required by '{source}'. See: "
+                               "https://postmarketos.org/depends")
+
+        # Determine pkgname
+        pkgname = package["pkgname"]
+        if is_conflict:
+            pkgname = f"!{pkgname}"
 
         # Append to todo/ret (unless it is a duplicate)
-        pkgname = package["pkgname"]
         if pkgname in ret:
             logging.verbose(f"{pkgname}: already found")
         else:
-            depends = package["depends"]
-            logging.verbose(f"{pkgname}: depends on: {','.join(depends)}")
-            if depends:
-                todo += depends
+            if not is_conflict:
+                depends = package["depends"]
+                logging.verbose(f"{pkgname}: depends on: {','.join(depends)}")
+                if depends:
+                    todo += depends
+                    for dep in depends:
+                        if dep not in required_by:
+                            required_by[dep] = set()
+                        required_by[dep].add(pkgname_depend)
             ret.append(pkgname)
     return ret
