@@ -1,4 +1,4 @@
-# Copyright 2021 Martijn Braam
+# Copyright 2022 Martijn Braam
 # SPDX-License-Identifier: GPL-3.0-or-later
 import glob
 import os
@@ -52,11 +52,11 @@ def ssh_install_apks(args, user, host, port, paths):
 
     logging.info(f"Installing packages at {user}@{host}")
     add_cmd = ['sudo', '-p', pmb.config.sideload_sudo_prompt,
-               '-S', 'apk', 'add'] + remote_paths
+               '-S', 'apk', '--wait', '30', 'add'] + remote_paths
     add_cmd = pmb.helpers.run.flat_cmd(add_cmd)
     clean_cmd = pmb.helpers.run.flat_cmd(['rm'] + remote_paths)
     command = ['ssh', '-t', '-p', port, f'{user}@{host}',
-               f'{add_cmd}; {clean_cmd}']
+               f'{add_cmd}; rc=$?; {clean_cmd}; exit $rc']
     pmb.helpers.run.user(args, command, output="tui")
 
 
