@@ -43,7 +43,8 @@ def test_bootimg_invalid_file(args):
 
 def test_bootimg_normal(args):
     path = pmb_test.const.testdata + "/bootimg/normal-boot.img"
-    output = {"base": "0x80000000",
+    output = {"header_version": "0",
+              "base": "0x80000000",
               "kernel_offset": "0x00008000",
               "ramdisk_offset": "0x04000000",
               "second_offset": "0x00f00000",
@@ -73,7 +74,8 @@ def test_bootimg_qcdt(args):
 
 def test_bootimg_mtk_mkimage(args):
     path = pmb_test.const.testdata + "/bootimg/mtk_mkimage-boot.img"
-    output = {"base": "0x10000000",
+    output = {"header_version": "0",
+              "base": "0x10000000",
               "kernel_offset": "0x00008000",
               "ramdisk_offset": "0x01000000",
               "second_offset": "0x00f00000",
@@ -88,7 +90,8 @@ def test_bootimg_mtk_mkimage(args):
 
 def test_bootimg_mtk_mkimage_recovery(args):
     path = pmb_test.const.testdata + "/bootimg/mtk_mkimage-boot-recovery.img"
-    output = {"base": "0x80000000",
+    output = {"header_version": "0",
+              "base": "0x80000000",
               "kernel_offset": "0x00008000",
               "ramdisk_offset": "0x04000000",
               "second_offset": "0x00f00000",
@@ -103,7 +106,8 @@ def test_bootimg_mtk_mkimage_recovery(args):
 
 def test_bootimg_dtb_second(args):
     path = pmb_test.const.testdata + "/bootimg/dtb-second-boot.img"
-    output = {"base": "0x00000000",
+    output = {"header_version": "0",
+              "base": "0x00000000",
               "kernel_offset": "0x00008000",
               "ramdisk_offset": "0x02000000",
               "second_offset": "0x00f00000",
@@ -116,6 +120,23 @@ def test_bootimg_dtb_second(args):
     assert pmb.parse.bootimg(args, path) == output
 
 
+def test_bootimg_v2(args):
+    path = pmb_test.const.testdata + "/bootimg/boot-header-v2.img"
+    output = {"header_version": "2",
+              "base": "0x40078000",
+              "kernel_offset": "0x00008000",
+              "ramdisk_offset": "0x07c08000",
+              "second_offset": "0x00e10000",
+              "tags_offset": "0x0bc08000",
+              "pagesize": "2048",
+              "dtb_offset": "0x0bc08000",
+              "cmdline": "bootopt=64S3,32N2,64N2 systempart=/dev/mapper/system",
+              "qcdt": "false",
+              "mtk_mkimage": "false",
+              "dtb_second": "false"}
+    assert pmb.parse.bootimg(args, path) == output
+
+
 def test_bootimg_v3(args):
     path = pmb_test.const.testdata + "/bootimg/boot-header-v3.img"
     output = {"header_version": "3",
