@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
 import sys
@@ -23,20 +23,20 @@ def args(request, tmpdir):
     apkindex_path = str(tmpdir) + "/APKINDEX.tar.gz"
     open(apkindex_path, "a").close()
     lastmod = os.path.getmtime(apkindex_path)
-    args.cache["apkindex"][apkindex_path] = {"lastmod": lastmod,
-                                             "multiple": {}}
+    pmb.helpers.other.cache["apkindex"][apkindex_path] = {"lastmod": lastmod,
+                                                          "multiple": {}}
     return args
 
 
-def cache_apkindex(args, version):
+def cache_apkindex(version):
     """
     Modify the cache of the parsed binary package repository's APKINDEX
     for the "hello-world" package.
     :param version: full version string, includes pkgver and pkgrl (e.g. 1-r2)
     """
-    apkindex_path = list(args.cache["apkindex"].keys())[0]
+    apkindex_path = list(pmb.helpers.other.cache["apkindex"].keys())[0]
 
-    providers = args.cache[
+    providers = pmb.helpers.other.cache[
         "apkindex"][apkindex_path]["multiple"]["hello-world"]
     providers["hello-world"]["version"] = version
 
@@ -44,25 +44,25 @@ def cache_apkindex(args, version):
 def test_build_is_necessary(args):
     # Prepare APKBUILD and APKINDEX data
     aport = pmb.helpers.pmaports.find(args, "hello-world")
-    apkbuild = pmb.parse.apkbuild(args, aport + "/APKBUILD")
+    apkbuild = pmb.parse.apkbuild(f"{aport}/APKBUILD")
     apkbuild["pkgver"] = "1"
     apkbuild["pkgrel"] = "2"
-    indexes = list(args.cache["apkindex"].keys())
+    indexes = list(pmb.helpers.other.cache["apkindex"].keys())
     apkindex_path = indexes[0]
     cache = {"hello-world": {"hello-world": {"pkgname": "hello-world",
                                              "version": "1-r2"}}}
-    args.cache["apkindex"][apkindex_path]["multiple"] = cache
+    pmb.helpers.other.cache["apkindex"][apkindex_path]["multiple"] = cache
 
     # Binary repo has a newer version
-    cache_apkindex(args, "999-r1")
+    cache_apkindex("999-r1")
     assert pmb.build.is_necessary(args, None, apkbuild, indexes) is False
 
     # Aports folder has a newer version
-    cache_apkindex(args, "0-r0")
+    cache_apkindex("0-r0")
     assert pmb.build.is_necessary(args, None, apkbuild, indexes) is True
 
     # Same version
-    cache_apkindex(args, "1-r2")
+    cache_apkindex("1-r2")
     assert pmb.build.is_necessary(args, None, apkbuild, indexes) is False
 
 
@@ -71,9 +71,9 @@ def test_build_is_necessary_no_binary_available(args):
     APKINDEX cache is set up to fake an empty APKINDEX, which means that the
     hello-world package has not been built yet.
     """
-    indexes = list(args.cache["apkindex"].keys())
+    indexes = list(pmb.helpers.other.cache["apkindex"].keys())
     aport = pmb.helpers.pmaports.find(args, "hello-world")
-    apkbuild = pmb.parse.apkbuild(args, aport + "/APKBUILD")
+    apkbuild = pmb.parse.apkbuild(f"{aport}/APKBUILD")
     assert pmb.build.is_necessary(args, None, apkbuild, indexes) is True
 
 
