@@ -1,4 +1,4 @@
-# Copyright 2021 Oliver Smith
+# Copyright 2022 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import pytest
 import sys
@@ -19,10 +19,10 @@ def args(tmpdir, request):
     return args
 
 
-def test_subpackages(args):
+def test_subpackages():
     testdata = pmb_test.const.testdata
     path = testdata + "/apkbuild/APKBUILD.subpackages"
-    apkbuild = pmb.parse.apkbuild(args, path, check_pkgname=False)
+    apkbuild = pmb.parse.apkbuild(path, check_pkgname=False)
 
     subpkg = apkbuild["subpackages"]["simple"]
     assert subpkg["pkgdesc"] == ""
@@ -36,14 +36,14 @@ def test_subpackages(args):
     # Successful extraction
     path = (testdata + "/init_questions_device/aports/device/testing/"
             "device-nonfree-firmware/APKBUILD")
-    apkbuild = pmb.parse.apkbuild(args, path)
+    apkbuild = pmb.parse.apkbuild(path)
     subpkg = (apkbuild["subpackages"]
               ["device-nonfree-firmware-nonfree-firmware"])
     assert subpkg["pkgdesc"] == "firmware description"
 
     # Can't find the pkgdesc in the function
     path = testdata + "/apkbuild/APKBUILD.missing-pkgdesc-in-subpackage"
-    apkbuild = pmb.parse.apkbuild(args, path, check_pkgname=False)
+    apkbuild = pmb.parse.apkbuild(path, check_pkgname=False)
     subpkg = (apkbuild["subpackages"]
               ["missing-pkgdesc-in-subpackage-subpackage"])
     assert subpkg["pkgdesc"] == ""
@@ -73,9 +73,9 @@ def test_kernels(args):
     assert func(args, device) == ret
 
 
-def test_depends_in_depends(args):
+def test_depends_in_depends():
     path = pmb_test.const.testdata + "/apkbuild/APKBUILD.depends-in-depends"
-    apkbuild = pmb.parse.apkbuild(args, path, check_pkgname=False)
+    apkbuild = pmb.parse.apkbuild(path, check_pkgname=False)
     assert apkbuild["depends"] == ["first", "second", "third"]
 
 
@@ -107,6 +107,9 @@ def test_parse_attributes():
     assert func("pkgname", 'pkgname="test" # random comment\npkgrel=3') == \
         (True, "test", 0)
 
+    assert func("pkgver", 'pkgver=2.37 # random comment\npkgrel=3') == \
+           (True, "2.37", 0)
+
     assert func("depends", "depends='\nfirst\nsecond\nthird\n'#") == \
         (True, "first second third", 4)
 
@@ -124,9 +127,9 @@ def test_parse_attributes():
     assert str(e.value).startswith("Can't find closing")
 
 
-def test_variable_replacements(args):
+def test_variable_replacements():
     path = pmb_test.const.testdata + "/apkbuild/APKBUILD.variable-replacements"
-    apkbuild = pmb.parse.apkbuild(args, path, check_pkgname=False)
+    apkbuild = pmb.parse.apkbuild(path, check_pkgname=False)
     assert apkbuild["pkgdesc"] == "this should not affect variable replacement"
     assert apkbuild["url"] == "replacements variable string-replacements"
     assert list(apkbuild["subpackages"].keys()) == ["replacements", "test"]
@@ -137,7 +140,7 @@ def test_variable_replacements(args):
                                       "replacement")
 
 
-def test_parse_maintainers(args):
+def test_parse_maintainers():
     path = pmb_test.const.testdata + "/apkbuild/APKBUILD.lint"
     maintainers = [
         "Oliver Smith <ollieparanoid@postmarketos.org>",
@@ -147,7 +150,7 @@ def test_parse_maintainers(args):
     assert pmb.parse._apkbuild.maintainers(path) == maintainers
 
 
-def test_parse_unmaintained(args):
+def test_parse_unmaintained():
     path = (f"{pmb_test.const.testdata}/apkbuild"
             "/APKBUILD.missing-pkgdesc-in-subpackage")
     assert pmb.parse._apkbuild.unmaintained(path) == "This is broken!"
